# NAME

shchemes - Automatically theming your apps with the power of the shell.

# SYNOPSIS

```
shchemes METHOD [OPTIONS]
```

# DESCRIPTION

## SCHEME {#SCHEME}
SCHEME is an environment variable that determines the default color
scheme to operate on.

Schemes are in a format of \<scheme format\>:\<scheme name\>.

If no format is provided, base16 is assumed.

## Examples
```
SCHEME="base16:heetch"

SCHEME="base24:monokai"
```

See also: [`--scheme`](#scheme)

## OPTIONS

## `--scheme` {#scheme}
Sets the color scheme to operate on, regardless of the value of SCHEME.

## Example
```
shchemes create_theme kitty --scheme=base16:blueforest
```

See also: [SCHEME]{#scheme}

## `--format` {#format}
Sets the color scheme format of the output file. This defaults to the
same format as your color scheme.

## Example
```
shchemes create_theme alacritty --format=base24
```

## METHODS

## create_theme {#create_theme}

Apply the color scheme to the template for a given app
```
shchemes create_theme TARGET
```

See also: [`--format`](#format)

## inject

In the given file, looks for a comment that indicates a Shchemes injection block, runs its command in a shell with Shchemes sourced, and pipes the stdout into the content of the injection block.
```
shchemes inject PATH
```

See also: [`create_theme`](#create_theme)

## install_tinted_scheme {#install_tinted_scheme}
Installs a color scheme from the [tinted-theming/schemes](https://github.com/tinted-theming/schemes).

You can find a gallery of the base16 themes here:
[https://tinted-theming.github.io/base16-gallery/](https://tinted-theming.github.io/base16-gallery/)
```
shchemes install_tinted_scheme
```

See also: [`SCHEME`](#SCHEME) [`--scheme`](#scheme) [`convert_tinted_scheme`](#convert_tinted_scheme)

## convert_tinted_scheme {#convert_tinted_scheme}
Converts a tinted-theming scheme to a .properties format for use in shchemes.

```
shchemes convert_tinted_scheme pico.yaml
cat pico.yaml > shchemes convert_tinted_scheme
```

See also: [`install_tinted_scheme`](#install_tinted_scheme)

## install_tinted_template {#install_tinted_template}
Downloads, converts, and installs a tinted-theming template from a given url.

```
shchemes install_tinted_template https://raw.githubusercontent.com/tinted-theming/base16-emacs/main/templates/default.mustache
```

It is recommended that you use already-maintained shchemes templates rather than just installing and converting third party ones.

See also: [`convert_tinted_template`](#convert_tinted_template)

## convert_tinted_template {#convert_tinted_template}
Converts a tinted-theming .mustache template to a shchemes template.

```
shchemes convert_tinted_template default.mustache > ~/shchemes/base16/templates/emacs.mustache
``` 

See also: [`install_tinted_template`](#install_tinted_template)

## manual, man, help
Opens this manual

# AUTHOR

Shchemes is written by Dakedres
